@@ -5,7 +5,10 @@
   qw| CGI::Builder::DFVCheck
       CGI::Builder::Magic
     |
-
+; sub OH_init
+   { $_[0]->tm
+   }
+   
 ; sub SH_index
    { my $s = shift
    ; $s->dfv_check( { required => 'email'
